@@ -11,8 +11,7 @@ __all__ = ["nicknames"]
 
 nicknames = """
 aaron,erin,ronnie,ron
-abbie,abby,abigail
-abe,abraham,abram
+abbigail,nabby,abby,gail,abbi,abbey
 abednego,bedney
 abel,ebbie,ab,abe,eb
 abiel,ab
@@ -20,25 +19,24 @@ abigail,nabby,abby,gail
 abijah,ab,bige
 abner,ab
 abraham,ab,abe
-abram,ab
+abram,ab,abe
 absalom,app,ab,abbie
 ada,addy
 adaline,delia,lena,dell,addy,ada
-adam,edie,ade
-addy,adele
+addison,addie,addy
 adela,della
 adelaide,heidi,adele,dell,addy,della
 adelbert,del,albert,delbert,bert
-adele,dell
+adele,addy,dell
 adeline,delia,lena,dell,addy,ada
 adelphia,philly,delphia,adele,dell,addy
 adolphus,dolph,ado,adolph
 adrian,rian
-adrienne,adrian
+adriane,riane
+adrienne,addie,rienne,enne
 agatha,aggy
 agnes,inez,aggy,nessa
 aileen,lena,allie
-al,albert,bert,alex
 alan,al
 alanson,al,lanson
 alastair,al
@@ -47,9 +45,10 @@ albert,bert,al
 alberta,bert,allie,bertie
 aldo,al
 aldrich,riche,rich
+aleksandr,alex,alek
 aleva,levy,leve
-alex,alexandra,alexander
-alexander,alex,al,sandy
+alex,al
+alexander,alex,al,sandy,alec
 alexandra,alex,sandy,alla,sandra
 alexandria,drina,alexander,alla,sandra
 alexis,lexi
@@ -60,15 +59,20 @@ algernon,algy
 alice,lisa,elsie,allie
 alicia,lisa,elsie,allie
 aline,adeline
-alison,ali
+alison,ali,allie
+alixandra,alix
 allan,al
 allen,al
 allisandra,allie
+allison,ali,allie
+allyson,ally,allie
+allyssa,ally,allie
 almena,mena,allie
 almina,minnie
 almira,myra
 alonzo,lon,al,lonzo
 alphinias,alphus
+althea,ally
 alverta,virdie,vert
 alyssa,lissia,al,ally
 alzada,zada
@@ -78,20 +82,23 @@ amelia,amy,mel,millie,emily
 amos,moses
 anastasia,ana,stacy
 anderson,andy
+andre,drea
 andrea,drea,rea,andrew
 andrew,andy,drew
-andy,andrew,drew
-angela,angelica,angelina,angel,angeline,jane,angie
-angelina,lina
-ann,nana,nan,nancy,annie,nanny
-anna,anne,ann,annie
-anne,annie,nana,ann,nan,nanny,nancy
+andriane,ada,adri,rienne
+angela,angel,angie
+angelica,angie,angel
+angelina,angel,angie,lina
+ann,annie,nan
+anna,anne,ann,annie,nan
+anne,annie,ann,nan
 annette,anna,nettie
 annie,ann,anna
 anselm,ansel,selma,anse,ance
-anthony,tony
+anthony,ant,tony
 antoinette,tony,netta,ann
 antonia,tony,netta,ann
+antonio,ant,tony
 appoline,appy,appie
 aquilla,quil,quillie
 ara,belle,arry
@@ -100,7 +107,7 @@ arabelle,ara,bella,arry,belle
 araminta,armida,middie,ruminta,minty
 archibald,archie
 archilles,kill,killis
-ariadne,arie
+ariadne,arie,ari
 arielle,arie
 aristotle,telly
 arizona,onie,ona
@@ -111,7 +118,7 @@ armilda,milly
 arminda,mindie
 arminta,minite,minnie
 arnold,arnie
-art,arthur
+aron,erin,ronnie,ron
 artelepsa,epsey
 artemus,art
 arthur,art
@@ -120,6 +127,7 @@ arzada,zaddi
 asahel,asa
 asaph,asa
 asenath,sene,assene,natty
+ashley,ash,leah,lee
 aubrey,bree
 audrey,dee
 august,gus
@@ -148,9 +156,8 @@ beck,becky
 bedelia,delia,bridgit
 belinda,belle,linda
 bella,belle,arabella,isabella
-ben,benjamin,bennie
 benedict,bennie,ben
-benjamin,benjy,jamie,bennie,ben
+benjamin,benjy,jamie,bennie,ben,benny
 benjy,benjamin
 bernard,barney,bernie,berney
 berney,bernie
@@ -171,13 +178,19 @@ bobby,rob,bob
 boetius,bo
 brad,bradford,ford
 bradford,ford,brad
+bradley,brad
 brady,brody
+breanna,bree,bri
+breeanna,bree
 brenda,brandy
 brian,bryan,bryant
+brianna,bri
 bridget,bridie,biddy,bridgie,biddie
 brittany,britt
+brittney,britt
 broderick,ricky,brody,brady,rick
-cal,calvin
+caitlin,cait,caity
+caitlyn,cait,caity
 caldonia,calliedona
 caleb,cal
 california,callie
@@ -191,6 +204,7 @@ candace,candy,dacey
 carlotta,lottie
 carlton,carl
 carmellia,mellia
+carmelo,melo
 carmon,charm,cammie,carm
 carol,lynn,carrie,carolann,cassie,caroline,carole
 carolann,carol,carole
@@ -201,7 +215,7 @@ carthaette,etta,etty
 casey,k.c.
 casper,jasper
 cassandra,sandy,cassie,sandra
-cassie,cassandra
+cassidy,cassie,cass
 caswell,cass
 catherine,kathy,katy,lena,kittie,kit,trina,cathy,kay,cassie
 cathleen,kathy,katy,lena,kittie,kit,trina,cathy,kay,cassie
@@ -215,8 +229,7 @@ charles,charlie,chuck,carl,chick
 charlie,charles,chuck
 charlotte,char,sherry,lottie,lotta
 chauncey,chan
-cher,sher
-cheryl,sheryl
+cheryl,cher
 chesley,chet
 chester,chet
 chet,chester
@@ -226,8 +239,10 @@ chris,christina,christopher,christine
 christa,chris
 christian,chris,kit
 christiana,kris,kristy,ann,tina,christy,chris,crissy
+christiano,chris
 christina,kris,kristy,tina,christy,chris,crissy
 christine,kris,kristy,chrissy,tina,chris,crissy
+christoph,chris
 christopher,chris,kit
 christy,crissy
 cicely,cilla
@@ -259,26 +274,19 @@ cornelius,conny,niel,corny,con
 cory,coco,cordy,ree
 courtney,curt,court
 crystal,chris,tal,stal,crys
-curt,curtis
 curtis,curt
-cy,cyrus
 cynthia,cintha,cindy
 cyrenius,swene,cy,serene,renius,cene
 cyrus,cy
-daisy,margaret
-dal,dahl
-dalton,dahl
-dan,danny,daniel
-daniel,dan,danny
+dahl,dal
+dalton,dahl,dal
+daniel,dan,danny,dann
 danielle,ellie,dani
 danny,daniel
 daphne,daph,daphie
 darlene,lena,darry
-dave,david
-davey,david
 david,dave,day,davey
 deanne,ann,dee
-deb,deborah,debra
 debbie,deb,debra,deborah,debby
 debby,deb
 debora,deb,debbie,debby
@@ -289,15 +297,13 @@ delbert,bert,del
 delia,fidelia,cordelia,delius
 delilah,lil,lila,dell,della
 deliverance,delly,dilly,della
-dell,della
-della,adela,delilah,adelaide
+della,adela,delilah,adelaide,dell
 delores,lolly,lola,della,dee,dell
 delpha,philadelphia
 delphine,delphi,del,delf
 demaris,dea,maris,mary
 demerias,dea,maris,mary
 democrates,mock
-denise,dennis
 dennis,denny
 dennison,denny
 derrick,ricky,eric,rick
@@ -309,26 +315,24 @@ dick,rick,richard
 dickson,dick
 domenic,dom
 dominic,dom
-don,donald
+dominick,dom
 donald,dony,donnie,don,donny
-donnie,donald,donny
-donny,donald
+donovan,dony,donnie,don,donny
 dorcus,darkey
 dorinda,dorothea,dora
 doris,dora
 dorothea,doda,dora
 dorothy,dortha,dolly,dot,dotty
-dot,dotty
 dotha,dotty
+dotty,dot
 douglas,doug
-drew,andrew
 drusilla,silla
 duncan,dunk
 earnest,ernestine,ernie
-eb,ebbie
+ebbie,eb
 ebenezer,ebbie,eben,eb
-ed,eddie,eddy
-eddie,eddy
+eddie,ed
+eddy,ed
 edgar,ed,eddie,eddy
 edith,edie,edye
 edmond,ed,eddie,eddy
@@ -356,7 +360,7 @@ eliphalet,left
 elisa,lisa
 elisha,lish,eli
 eliza,elizabeth
-elizabeth,libby,lisa,lib,lizzie,eliza,betsy,liza,betty,bessie,bess,beth,liz
+elizabeth,libby,lisa,lib,lizzy,lizzie,eliza,betsy,liza,betty,bessie,bess,beth,liz
 ella,ellen
 ellen,nellie,nell,helen
 ellender,nellie,ellen,helen
@@ -426,42 +430,37 @@ frank,franklin
 frankie,frank,francis
 franklin,fran,frank
 franklind,frank
-fred,freddy,frederick
 freda,frieda
-frederica,frederick
+frederica,frederick,freddy
 frederick,freddie,freddy,fritz,fred
 fredericka,freddy,ricka,freda,frieda
 frieda,freddie,freddy,fred
-gabby,gabriella,gabe,gabrielle
-gabe,gabriel
 gabriel,gabe,gabby
 gabriella,ella,gabby
 gabrielle,ella,gabby
+garrick,garri
 genevieve,jean,eve,jenny
-geoff,geoffrey,jeffrey,jeff
 geoffrey,geoff,jeff
-george,jorge,georgiana
-georgia,george,georgiana
+george,georgie
+georgiana,georgia
 gerald,gerry,jerry
 geraldine,gerry,gerrie,jerry,dina
 gerhardt,gay
-gerrie,geraldine
-gerry,gerald,geraldine,jerry
-gert,gertie
-gertie,gertrude
+gertie,gertrude,gert
 gertrude,gertie,gert,trudy
-gil,gilbert
 gilbert,bert,gil,wilber
+giovanni,gio
 gloria,glory
 governor,govie
 greenberry,green,berry
-gregory,greg
+greggory,gregg
+gregory,greg,gory
 gretchen,margaret
 griselda,grissel
 gum,monty
 gus,gussie
-gustavus,gus
-gwen,gwendolyn,wendy
+gustavus,gus,gussie
+gwen,wendy
 gwendolyn,gwen,wendy
 hamilton,ham
 hannah,nan,nanny,anna
@@ -478,7 +477,6 @@ henrietta,hank,etta,etty,retta,nettie
 henry,hank,hal,harry
 hephsibah,hipsie
 hepsibah,hipsie
-herb,herbert
 herbert,bert,herb
 herman,harman,dutch
 hermione,hermie
@@ -517,6 +515,7 @@ jacob,jaap,jake,jay
 jacobus,jacob
 jacqueline,jackie,jack
 jahoda,hody,hodie,hoda
+jakob,jake
 james,jimmy,jim,jamie,jimmie,jem
 jamie,james
 jane,janie,jessie,jean,jennie
@@ -528,20 +527,20 @@ jayme,jay
 jean,jane,jeannie
 jeanette,jessie,jean,janet,nettie
 jeanne,jane,jeannie
-jeb,jebadiah
+jebadiah,jeb
 jedediah,dyer,jed,diah
-jedidiah,jed
-jeff,geoffrey,jeffrey
+jedidiah,dyer,jed,diah
 jefferey,jeff
 jefferson,sonny,jeff
+jeffery,jeff
 jeffrey,geoff,jeff
 jehiel,hiel
 jehu,hugh,gee
 jemima,mima
-jennet,jessie,jenny
-jennifer,jennie
-jenny,jennifer
+jennet,jessie,jenny,jenn
+jennifer,jennie,jenn,jen,jenny
 jeremiah,jereme,jerry
+jeremy,jezza,jez
 jerita,rita
 jerry,jereme,geraldine
 jessica,jessie
@@ -554,19 +553,17 @@ joann,jo
 joanna,hannah,jody,jo,joan
 joanne,jo
 jody,jo
-joe,joseph,joey
-joey,joseph
+joe,joey
 johanna,jo
 johannah,hannah,jody,joan,nonie
 johannes,jonathan,john,johnny
-john,jack,johnny,jock
-jon,john,nathan
-jonathan,john,nathan
+john,jack,johnny,jock,ian
+jonathan,john,nathan,jon,jonny,jonnie
+jonathon,jon,jonny,jonnie
 joseph,jody,jos,joe,joey
-josephine,fina,jody,jo,josey,joey
+josephine,fina,jody,jo,josey,joey,josie
 josetta,jettie
 josey,josophine
-josh,joshua
 joshua,jos,josh
 josiah,jos
 joyce,joy
@@ -582,6 +579,10 @@ julie,julia,jule
 june,junius
 junior,junie,june,jr
 justin,justus,justina
+kaitlin,kait,kaitie
+kaitlyn,kait,kaitie
+kaitlynn,kait,kaitie
+kameron,kam
 karonhappuck,karon,karen,carrie,happy
 kasey,k.c.
 katarina,catherine,tina
@@ -590,13 +591,13 @@ katelin,kay,kate,kaye
 katelyn,kay,kate,kaye
 katherine,kathy,katy,lena,kittie,kaye,kit,trina,cathy,kay,kate,cassie
 kathleen,kathy,katy,lena,kittie,kit,trina,cathy,kay,cassie
-kathryn,kathy
-katy,kathy
+kathryn,kathy,katie
+katy,kathy,katie
 kayla,kay
-ken,kenneth
 kendall,ken,kenny
 kendra,kenj,kenji,kay,kenny
 kendrick,ken,kenny
+kendrik,ken,kenny
 kenneth,ken,kenny,kendrick
 kenny,ken,kenneth
 kent,ken,kenny,kendrick
@@ -640,7 +641,6 @@ leonidas,lee,leon
 leonora,nora,nell,nellie
 leonore,nora,honor,elenor
 leroy,roy,lee,l.r.
-les,lester
 leslie,les
 lester,les
 letitia,tish,titia,lettice,lettie
@@ -652,17 +652,16 @@ lidia,lyddy
 lil,lilly,lily
 lillah,lil,lilly,lily,lolly
 lillian,lil,lilly,lolly
-lilly,lily
+lilly,lily,lil
 lincoln,link
 linda,lindy,lynn
 lindy,lynn
 lionel,leon
-lisa,lizzie,alice,liz,melissa
+lisa,liz
 littleberry,little,berry,l.b.
-liz,elizabeth
-lizzie,elizabeth,liz
+lizzie,liz
 lois,lou,louise
-lon,lonzo
+lonzo,lon
 lorenzo,loren
 loretta,etta,lorrie,retta
 lorraine,lorrie
@@ -691,17 +690,22 @@ mabel,mehitabel,amabel
 mac,mc
 mack,mac,mc
 mackenzie,kenzy,mac,mack
+maddison,maddie,maddi
 maddy,madelyn,madeline,madge
 madeline,maggie,lena,magda,maddy,madge
+madeline,maddie,maddi
 madie,madeline,madelyn
 madison,mattie,maddy
+maegen,meg
 magdalena,maggie,lena
 magdelina,lena,magda,madge
 mahala,hallie
+makayla,kayla
 malachi,mally
 malcolm,mac,mal,malc
 malinda,lindy
 manda,mandy
+mandie,amanda
 mandy,amanda
 manerva,minerva,nervie,eve,nerva
 manny,manuel
@@ -715,7 +719,6 @@ margarita,maggie,meg,metta,midge,greta,megan,maisie,madge,marge,daisy,peggie,rit
 marge,margery,margaret,margaretta
 margie,marjorie,margie
 marguerite,peggy
-margy,marjorie
 mariah,mary,maria
 marian,marianna,marion
 marie,mae
@@ -723,6 +726,7 @@ marietta,mariah,mercy,polly,may,molly,mitzi,minnie,mollie,mae,maureen,marion,mar
 marilyn,mary
 marion,mary
 marissa,rissa
+marjorie,margie
 marjorie,margy,margie
 marsha,marcie,mary
 martha,marty,mattie,mat,patsy,patty
@@ -732,10 +736,11 @@ martine,tine
 marv,marvin
 marvin,marv
 mary,mamie,molly,mae,polly,mitzi
+masayuki,masa
 mat,mattie
+mathew,mat,maty
 mathilda,tillie,patty
 matilda,tilly,maud,matty
-matt,mathew,matthew
 matthew,thys,matt,thias,mattie,matty
 matthias,thys,matt,thias
 maud,middy
@@ -743,11 +748,14 @@ maureen,mary
 maurice,morey
 mavery,mave
 mavine,mave
+maximillian,max
 maxine,max
+maxwell,max
 may,mae
 mckenna,ken,kenna,meaka
 medora,dora
 megan,meg
+meghan,meg
 mehitabel,hetty,mitty,mabel,hitty
 melanie,mellie
 melchizedek,zadock,dick
@@ -761,7 +769,8 @@ mercedes,merci,sadie,mercy
 merv,mervin
 mervyn,merv
 micajah,cage
-michael,micky,mike,micah,mick
+michael,micky,mike,micah,mick,mikey
+micheal,mike,miky,mikey
 michelle,mickey
 mick,micky
 mike,micky,mick,michael
@@ -798,14 +807,14 @@ nathaniel,than,nathan,nate,nat,natty
 nelle,nelly
 nelson,nels
 newt,newton
-nicholas,nick,claes,claas
-nick,nik,nicholas
-nickie,nicholas
-nicodemus,nick
+nicholas,nick,claes,claas,nic,nicky,nico,nickie
+nicodemus,nick,nic,nicky,nico,nickie
 nicole,nole,nikki,cole
-nik,nick
+nikolas,nick,claes,nic,nicky,nico,nickie
+nikole,nikki
 nora,nonie
 norbert,bert,norby
+norbusamte,norbu
 nowell,noel
 obadiah,dyer,obed,obie,diah
 obedience,obed,beda,beedy,biddie
@@ -823,22 +832,20 @@ orphelia,phelia
 ossy,ozzy
 oswald,ozzy,waldo,ossy
 otis,ode,ote
-ozzy,oswald
 pamela,pam
 pandora,dora
 parmelia,amelia,milly,melia
 parthenia,teeny,parsuny,pasoonie,phenie
-pat,patrick,pat,patricia
 patience,pat,patty
-patricia,tricia,pat,patsy,patty
+patricia,tricia,pat,patsy,patty,patti
 patrick,pate,peter,pat,patsy,paddy
 patsy,patty
 patty,patricia
-paul,polly,paula,pauline
+paul,polly
 paula,polly,lina
 paulina,polly,lina
 pauline,polly
-peg,peggy
+peggy,peg
 pelegrine,perry
 penelope,penny
 percival,percy
@@ -846,12 +853,10 @@ peregrine,perry
 permelia,melly,milly,mellie
 pernetta,nettie
 persephone,seph,sephy
-pete,peter
 peter,pete,pate
 petronella,nellie
 pheney,josephine
 pheriba,pherbia,ferbie
-phil,phillip,philip
 philadelphia,delphia
 philander,fie
 philetus,leet,phil
@@ -880,8 +885,7 @@ ray,raymond
 raymond,ray
 reba,beck,becca
 rebecca,beck,becca,reba,becky
-reg,reggie
-reggie,reginald
+reggie,reginald,reg
 regina,reggie,gina
 reginald,reggie,naldo,reg,renny
 relief,leafa
@@ -891,20 +895,19 @@ rhoda,rodie
 rhodella,della
 rhyna,rhynie
 ricardo,rick,ricky
-rich,dick,rick,riche,richard
-richard,dick,dickon,dickie,dicky,rick,rich,ricky
-richie,richard
+rich,dick,rick
+richard,dick,dickon,dickie,dicky,rick,rich,ricky,richie
 rick,ricky
 ricky,dick,rich
 robert,hob,hobkin,dob,rob,bobby,dobbin,bob
 roberta,robbie,bert,bobbie,birdie,bertie
-roderick,rod,erick,rickie
+roderick,rod,erick,rickie,roddy
 rodger,roge,bobby,hodge,rod,robby,rupert,robin
+rodney,rod
 roger,roge,bobby,hodge,rod,robby,rupert,robin
 roland,rollo,lanny,orlando,rolly
-ron,ronald,ronnie,ronny
-ronald,naldo,ron,ronny
-ronnie,ronald
+ron,ronnie,ronny
+ronald,naldo,ron,ronny,ronnie
 ronny,ronald
 rosa,rose
 rosabel,belle,roz,rosa,rose
@@ -920,19 +923,14 @@ rosina,sina
 roxane,rox,roxie
 roxanna,roxie,rose,ann
 roxanne,roxie,rose,ann
-roz,rosalyn
-rube,reuben
 rudolph,dolph,rudy,olph,rolf
 rudolphus,dolph,rudy,olph,rolf
-rudy,rudolph
-russ,russell
 russell,russ,rusty
-rusty,russell
 ryan,ry
 sabrina,brina
+safieel,safie
 salome,loomie
 salvador,sal
-sam,sammy,samuel
 samantha,sammy,sam,mantha
 sammy,samuel
 sampson,sam
@@ -969,7 +967,6 @@ silence,liley
 silvester,vester,si,sly,vest,syl
 simeon,si,sion
 simon,si,sion
-sly,sylvester
 smith,smitty
 socrates,crate
 solomon,sal,salmon,sol,solly,saul,zolly
@@ -979,8 +976,8 @@ sophronia,frona,sophia,fronia
 stephan,steve
 stephanie,stephen,stephie,annie,steph
 stephen,steve,steph
-steve,stephen,steven
-steven,steve,steph
+steve,stevie
+steven,steve,steph,stevie
 stuart,stu
 sue,susie,susan
 sullivan,sully,van
@@ -1044,17 +1041,16 @@ vandalia,vannie
 vanessa,essa,vanna,nessa
 vernisee,nicey
 veronica,vonnie,ron,ronna,ronie,frony,franky,ronnie
-vic,vicki,victor,vicky
+vic,vicki,vicky
 vicki,vicky,victoria
 vickie,victoria
 vicky,victoria
-victor,vic
+victor,vic,vickie,vicky
 victoria,torie,vic,vicki,tory,vicky
-vin,vinny
-vince,vinnie
+vijay,vij
 vincent,vic,vince,vinnie,vin,vinny
-vincenzo,vic,vinnie,vin,vinny
-vinson,vinny
+vincenzo,vic,vinnie,vin,vinny,vince
+vinson,vinny,vinnie,vin
 viola,ola,vi
 violetta,lettie
 virginia,jane,jennie,ginny,virgy,ginger
@@ -1067,13 +1063,15 @@ washington,wash
 webster,webb
 wendy,wen
 wesley,wes
+westley,west,wes,farmboy
 wilber,will,bert
 wilbur,willy,willie
 wilda,willie
-wilfred,will,willie,fred
+wilfred,will,willie,fred,wil
+wilhelm,wil,willie
 wilhelmina,mina,wilma,willie,minnie
 will,bill,willie,wilbur,fred
-william,willy,bell,bela,bill,will,billy,willie
+william,willy,bell,bela,bill,will,billy,willie,wil
 willie,william,fred
 willis,willy,bill
 wilma,william,billiewilhelm
@@ -1086,10 +1084,13 @@ winny,winnifred
 winton,wint
 woodrow,woody,wood,drew
 yeona,onie,ona
+yoshihiko,yoshi
 yulan,lan,yul
 yvonne,vonna
 zach,zachariah
-zachariah,zachy,zach,zeke
+zachariah,zachy,zach,zeke,zac,zack,zak,zakk
+zachary,zachy,zach,zeke,zac,zack,zak,zakk
+zachery,zachy,zach,zeke,zac,zack,zak,zakk
 zebedee,zeb
 zedediah,dyer,zed,diah
 zephaniah,zeph
